<?php
/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

/*
 * Created on 2 oct. 07 by AEL Sarl for
 * 
 * osCommerce, Open Source E-Commerce Solutions
 * http://www.oscommerce.com
 *
 * Copyright (c) 2003 osCommerce
 *
 * Released under the GNU General Public License
 * 
 */

require_once("OpensiStructure.php");

class OpensiPerson implements OpensiStructure {
	
	const CIV = 0;
	const NOM = 1;
	const PRENOM = 2;
	const ENTREPRISE = 3;
	const ADRESSE = 4;
	const COMPADRESSE = 5;
	const ADRESSE3 = 6;
	const CP = 7;
	const VILLE = 8;
	const PAYS = 9;	
	
	private $civility;
	
	/**
	 * Build a Person
	 * 
	 * @param	array	$person		a person, an array with personal parameters
	 */
	public function __construct($person) {
		$this->setCivility($person[self::CIV]);
		$this->firstname = $person[self::PRENOM];
		$this->lastname = $person[self::NOM];
		$this->country = $person[self::PAYS];
		$this->person = $person;
	}
	
	/**
	 * Set the civility attribute
	 * 
	 * @param	string	$civ	civility to set
	 */
	 public function setCivility($civ) {
	 	$this->civility = ($civ == 'f' ? 2 : 1);
	 }
	 
	/**
	 * Set the civility, firstname and the lastname, knowing the complete name.
	 * It uses the address book to do so
	 * 
	 * @param	string	$name	a complete name, firstname and lastname joined by space
	 */
	public function setFullCivility($name) {
		$civility_query = tep_db_query(
                              "SELECT IF(entry_gender != 'f', 1, 2) AS entry_civility, entry_firstname, entry_lastname" . 
		                      " FROM " . TABLE_ADDRESS_BOOK .
		                      " WHERE CONCAT_WS(' ', entry_firstname, entry_lastname) = '" . $name . "'");
		$civility = tep_db_fetch_array($civility_query);
		if (tep_not_null($civility)) {
			$this->civility = $civility['entry_civility'];
			$this->firstname = $civility['entry_firstname'];
			$this->lastname = $civility['entry_lastname'];
		} else { // should be impossible: every name is a concatenation of firstname and lastname
			$this->civility = 0;
			$this->firstname = '';
			$this->lastname = '';
		}	                      
	}
	
	/**
	 * Get the civility attribute
	 * 
	 * @return	string	the civility attribute
	 */
	public function getCivility() {
		return $this->civility;
	}
	
	public function prepareUpload() {
		$prepared = $this->person;
		// needed in case of call to setFullCivility
		$prepared[self::CIV] = $this->civility;
		$prepared[self::PRENOM] = $this->firstname;
		$prepared[self::NOM] = $this->lastname;
		//$prepared[self::VILLE] = soap_encode($this->city);
		return $prepared;
	}
}

class OpensiCustomer implements OpensiStructure {
	
	const ID = 0;
	const EMAIL = 1;
	const TEL = 2;
	const FAX = 3;
	const PERSONNE = 4;
	
	/**
	 * Build a Customer object
	 * 
	 * @param	array			$customer	a customer, an array of customer parameters
	 * @param 	OpensiPerson	$person		a person, as OpenSI sees it
	 */
	public function __construct($customer, $person=null) {
		$this->customers_person = $person;
		$this->customer = $customer;
	}
	
	/**
	 * Prepare a product for an upload toward the OpenSI server
	 */
	public function prepareUpload() {
		$prepared = $this->customer;
		
		$prepared_person = ($this->customers_person ? $this->customers_person->prepareUpload() : array());
		$prepared[self::PERSONNE] = $prepared_person;
		return $prepared;	
	}
	
}
?>
